@@ -170,15 +170,15 @@ class TalkAdd(TalkNotificationView):
     recipients_finder = ("manager_finder",)
 
     content = _(
-        u""
-        u"Dear %(firstname)s %(lastname)s,\n"
-        u"\n"
-        u"The talk '%(talk_name)s' was added on %(date)s.\n"
-        u"\n"
-        u"Sincerely,\n"
-        u"\n"
-        u"--\n"
-        u"The %(conference)s organizing committee.\n"
+        ""
+        "Dear %(firstname)s %(lastname)s,\n"
+        "\n"
+        "The talk '%(talk_name)s' was added on %(date)s.\n"
+        "\n"
+        "Sincerely,\n"
+        "\n"
+        "--\n"
+        "The %(conference)s organizing committee.\n"
     )
 
     def subject(self):
@@ -209,15 +209,15 @@ class TalkUpdate(TalkNotificationView):
     __select__ = TalkNotificationView.__select__ & entity_really_edited()
 
     content = _(
-        u""
-        u"Dear %(firstname)s %(lastname)s,\n"
-        u"\n"
-        u"The talk '%(talk_name)s' was modified on %(date)s.\n"
-        u"\n"
-        u"Sincerely,\n"
-        u"\n"
-        u"--\n"
-        u"The %(conference)s organizing committee.\n"
+        ""
+        "Dear %(firstname)s %(lastname)s,\n"
+        "\n"
+        "The talk '%(talk_name)s' was modified on %(date)s.\n"
+        "\n"
+        "Sincerely,\n"
+        "\n"
+        "--\n"
+        "The %(conference)s organizing committee.\n"
     )
 
     def subject(self):
@@ -229,15 +229,15 @@ class TalkStatusUpdate(StatusChangeMixIn, TalkNotificationView):
     recipients_finder = ("manager_finder", "interested_by_finder")
 
     content = _(
-        u""
-        u"Dear user,\n\n"
-        u"The '%(title)s' status was updated from '%(previous_state)s' to '%(current_state)s'.\n\n"
-        u"Sincerely,\n"
-        u"\n"
-        u"--\n"
-        u"The conference organizing committee.\n"
+        ""
+        "Dear user,\n\n"
+        "The '%(title)s' status was updated from '%(previous_state)s' to '%(current_state)s'.\n\n"
+        "Sincerely,\n"
+        "\n"
+        "--\n"
+        "The conference organizing committee.\n"
     )
 
     def subject(self):
         entity = self.cw_rset.get_entity(0, 0)
-        return _(u"[%s] talk status was updated" % entity.in_track[0].in_conf[0].title)
+        return _("[%s] talk status was updated" % entity.in_track[0].in_conf[0].title)
