@@ -8,7 +8,7 @@ from cubicweb.devtools.fill import ValueGenerator
 
 class MyValueGenerator(ValueGenerator):
     def generate_Sponsor_url(self, entity, index):
-        return u"http://sponsor.example.com"
+        return "http://sponsor.example.com"
 
 
 # necessary trick to avoid cw assertion error
